@@ -8,19 +8,19 @@
 //! It can multiple accessing data of multiple MumbleLinks, and allows multiple clients
 //! to request the data.
 
-use std::path::PathBuf;
+use std::{fmt::Debug, path::PathBuf};
 
 use log::LevelFilter;
 
-pub mod cross_platform;
-pub mod mlp {
-    tonic::include_proto!("mlp");
-}
+// pub mod mlp {
+//     tonic::include_proto!("mlp");
+// }
+pub mod mlink;
 
 #[cfg(target_os = "windows")]
 pub mod cli;
 #[cfg(target_os = "windows")]
-pub mod server;
+pub mod win;
 
 /// initializes global logging backend that is used by log macros
 /// Takes in a filter for stdout/stderr, a filter for logfile and finally the path to logfile
@@ -58,3 +58,10 @@ udp -> async, sync
 grpc -> async
 
 */
+fn log_error<T>(e: T) -> T
+where
+    T: Debug,
+{
+    log::error!("{:?}", &e);
+    e
+}
